@@ -20,7 +20,7 @@
 
 package App::MtAws::Command::Sync;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
@@ -32,12 +32,11 @@ use constant SHOULD_CREATE => 1;
 use constant SHOULD_TREEHASH => 2;
 use constant SHOULD_NOACTION => 0;
 
-use App::MtAws::JobProxy;
-use App::MtAws::JobListProxy;
-use App::MtAws::JobIteratorProxy;
-use App::MtAws::Job::FileCreate;
-use App::MtAws::Job::FileListDelete;
-use App::MtAws::Job::FileVerifyAndUpload;
+use App::MtAws::QueueJob::Iterator;
+use App::MtAws::QueueJob::VerifyAndUpload;
+use App::MtAws::QueueJob::Upload;
+use App::MtAws::QueueJob::Delete;
+
 use App::MtAws::ForkEngine  qw/with_forks fork_engine/;
 use App::MtAws::Journal;
 use App::MtAws::Utils;
@@ -91,22 +90,18 @@ sub next_modified
 		my $should_upload = should_upload($options, $file, $absfilename);
 
 		if ($should_upload == SHOULD_TREEHASH) {
-			return App::MtAws::JobProxy->new(job=>
-				App::MtAws::Job::FileVerifyAndUpload->new(filename => $absfilename,
-					relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
-					delete_after_upload => 1,
-					archive_id => $file->{archive_id},
-					treehash => $file->{treehash}
-			));
-		} elsif ($should_upload == SHOULD_CREATE) {
-			return App::MtAws::JobProxy->new(job=> App::MtAws::Job::FileCreate->new(
+			return App::MtAws::QueueJob::VerifyAndUpload->new(
 				filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
-				(finish_cb => sub {
-					App::MtAws::Job::FileListDelete->new(archives => [{
-						archive_id => $file->{archive_id}, relfilename => $relfilename
-					}])
-				})
-			));
+				delete_after_upload => 1,
+				archive_id => $file->{archive_id},
+				treehash => $file->{treehash}
+			);
+		} elsif ($should_upload == SHOULD_CREATE) {
+			return App::MtAws::QueueJob::Upload->new(
+				filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
+				delete_after_upload => 1,
+				archive_id => $file->{archive_id},
+			);
 		} elsif ($should_upload == SHOULD_NOACTION) {
 			next;
 		} else {
@@ -120,9 +115,10 @@ sub next_missing
 {
 	my ($options, $j) = @_;
 	if (my $rec = shift @{ $j->{listing}{missing} }) {
-		App::MtAws::Job::FileListDelete->new(archives => [{
-			archive_id => $j->latest($rec->{relfilename})->{archive_id}, relfilename => $rec->{relfilename}
-		}]);
+		return App::MtAws::QueueJob::Delete->new(
+			relfilename => $rec->{relfilename},
+			archive_id => $j->latest($rec->{relfilename})->{archive_id},
+		);
 	} else {
 		return;
 	}
@@ -133,13 +129,7 @@ sub next_new
 	my ($options, $j) = @_;
 	if (my $rec = shift @{ $j->{listing}{new} }) {
 		my ($absfilename, $relfilename) = ($j->absfilename($rec->{relfilename}), $rec->{relfilename});
-		if ($ENV{NEWFSM}) {
-			use App::MtAws::QueueJob::UploadMultipart;
-			App::MtAws::QueueJob::UploadMultipart->new(filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize});
-		} else {
-			App::MtAws::JobProxy->new(job =>
-				App::MtAws::Job::FileCreate->new(filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize}));
-		}
+		App::MtAws::QueueJob::Upload->new(filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize}, delete_after_upload => 0);
 	} else {
 		return;
 	}
@@ -183,12 +173,7 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				if ($ENV{NEWFSM}) {
-					use App::MtAws::QueueJob::Iterator;
-					push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
-				} else {
-					push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
-				}
+				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
 			}
 		}
 
@@ -198,7 +183,7 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
+				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
 			}
 		}
 		if ($options->{'delete-removed'}) {
@@ -206,23 +191,17 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
+				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
 			}
 		}
 
 		if (scalar @joblist) {
-			if ($ENV{NEWFSM}) {
-				confess unless @joblist == 1;
-				my $lt = $joblist[0];
-				my $P = fork_engine->{parent_worker};
-				$P->{journal} = $j;
-				my ($R) = $P->process($lt);
-				confess unless $R;
-			} else {
-				my $lt = App::MtAws::JobListProxy->new(jobs => \@joblist);
-				my ($R) = fork_engine->{parent_worker}->process_task($lt, $j);
-				confess unless $R;
-			}
+			my $lt = do {
+				confess unless @joblist >= 1;
+				App::MtAws::QueueJob::Iterator->new(iterator => sub { shift @joblist });
+			};
+			my ($R) = fork_engine->{parent_worker}->process_task($lt, $j);
+			confess unless $R;
 		}
 		$j->close_for_write();
 	}
