@@ -20,7 +20,7 @@
 
 package App::MtAws::HttpWriter;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
@@ -103,13 +103,13 @@ sub finish
 
 package App::MtAws::HttpSegmentWriter;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
 use utf8;
 use App::MtAws::Utils;
-use Fcntl qw/SEEK_SET LOCK_EX LOCK_UN/;
+use Fcntl qw/SEEK_SET LOCK_EX/;
 use Carp;
 use base qw/App::MtAws::HttpWriter/;
 
@@ -161,8 +161,7 @@ sub _flush
 		$fh->autoflush(1);
 		seek $fh, $self->{position}+$self->{incr_position}, SEEK_SET or delayed_confess "cannot seek() $!";
 		$self->{incr_position} += $self->_flush_buffers($fh);
-		flock $fh, LOCK_UN or delayed_confess;
-		close $fh or delayed_confess;
+		close $fh or delayed_confess; # close will unlock
 	}
 }
 
@@ -176,13 +175,12 @@ sub finish
 
 package App::MtAws::HttpFileWriter;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
 use utf8;
 use App::MtAws::Utils;
-use Fcntl qw/SEEK_SET LOCK_EX LOCK_UN/;
 use Carp;
 use base qw/App::MtAws::HttpWriter/;
 
@@ -234,7 +232,7 @@ sub finish
 
 package App::MtAws::HttpMemoryWriter;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
