@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::Iterator;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
@@ -33,10 +33,10 @@ sub init
 {
 	my ($self) = @_;
 
-	$self->{iterator}||confess;
+	$self->{iterator}||confess "iterator required";
+	$self->{maxcnt} ||= 30;
 	$self->{jobs} = {};
-	$self->{pending} = {};
-	$self->{task_autoincrement} = $self->{job_autoincrement} = 0;
+	$self->{job_autoincrement} = 0;
 	$self->enter('itt_only');
 }
 
@@ -55,29 +55,25 @@ sub get_next_itt
 sub find_next_job
 {
 	my ($self) = @_;
-	my $maxcnt = $self->{maxcnt}||30;
-	for my $job_id (keys %{$self->{jobs}}) {
+	my $maxcnt = $self->{maxcnt};
+	for my $job_id (keys %{$self->{jobs}}) { # Random order of jobs
 		my $job = $self->{jobs}{$job_id};
 		my $res = $job->next();
+		
+		# uncoverable branch false count:3
 		if ($res->{code} eq JOB_WAIT) {
-			if ($self->{one_by_one}) {
-				return JOB_WAIT;
-			} else {
-				return JOB_WAIT unless --$maxcnt;
-			}
+			return JOB_WAIT unless --$maxcnt;
 		} elsif ($res->{code} eq JOB_DONE) {
 			delete $self->{jobs}{$job_id};
 			return JOB_RETRY;
+
 		} elsif ($res->{code} eq JOB_OK) {
-			my $task_id = ++$self->{task_autoincrement};
-			$self->{pending}{$task_id} = 1;
 			return task($res->{task}, sub {
-				delete $self->{pending}{$task_id} or confess;
-				# TODO: test that this line does no present here: delete $self->{jobs}{$job_id} or confess;
 				$res->{task}{cb_task_proxy}->(@_);
 				return;
 			});
 		} else {
+			# uncoverable statement
 			confess;
 		}
 	}
@@ -101,8 +97,7 @@ sub on_itt_only
 sub on_itt_and_jobs
 {
 	my ($self) = @_;
-	my $maxcnt = $self->{maxcnt}||30;
-	if (my @r = find_next_job) { # try to process one pending job
+	if (my @r = $self->find_next_job) { # try to process one pending job
 		return @r;
 	} elsif ($self->get_next_itt) {
 		return JOB_RETRY # otherwise, get new job from iteartor and retry
