@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::MultipartPart;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
@@ -43,7 +43,7 @@ sub init
 	$self->{all_raised} = 0;
 	$self->{position} = 0;
 	$self->{th} = App::MtAws::TreeHash->new();
-	$self->{uploadparts} ||= {};
+	$self->{uploadparts} = {};
 
 	$self->enter('fist_part');
 }
