@@ -20,7 +20,7 @@
 
 package App::MtAws::QueueJob::UploadMultipart;
 
-our $VERSION = '1.051_2';
+our $VERSION = '1.059_1';
 
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ use base 'App::MtAws::QueueJob';
 sub init
 {
 	my ($self) = @_;
-	defined($self->{filename}) || $self->{stdin} || confess "no filename nor stdin";
+	defined($self->{filename}) xor $self->{stdin} or confess "filename xor stdin should be specified";
 	defined($self->{relfilename}) || confess "no relfilename";
 	$self->{partsize}||confess;
 	$self->enter("create");
@@ -48,7 +48,7 @@ sub on_create
 	my ($self) = @_;
 	return
 		state("wait"),
-		job( App::MtAws::QueueJob::MultipartCreate->new(map { $_ => $self->{$_} } qw/filename relfilename partsize/), sub {
+		job( App::MtAws::QueueJob::MultipartCreate->new(map { $_ => $self->{$_} } qw/filename stdin relfilename partsize/), sub {
 			my $j = shift;
 			defined($self->{$_} = $j->{$_}) or confess for qw/fh upload_id mtime/;
 			state("part")
@@ -82,17 +82,3 @@ sub on_finish
 1;
 
 __END__
-add sub {
-	my ($self) = @_;
-	App::MtAws::QueueJob::MultipartCreate(a, b, c)
-} => sub {
-	my $j = shift;
-	$self->{$_} = $j->{$_} or confess for qw/fh upload_id mtime/;
-}
-
-
-add sub {
-	App::MtAws::QueueJob::MultipartCreate(a, b, c)
-} => sub {
-	$self->{$_} = $j->{$_} or confess for qw/fh upload_id mtime/;
-}
